==> webform_booking-1.0.7.tar.gz: webform_booking/js/webform_booking.js <==
(function ($, Drupal) {
  Drupal.behaviors.WebformBooking = {
    attach: function (context, settings) {
      if (settings.webform_booking && settings.webform_booking.elements) {
        Object.keys(settings.webform_booking.elements).forEach(function (key) {
          var elementConfig = settings.webform_booking.elements[key]; // Correctly define elementConfig
          var elementId = elementConfig.elementId;
          var formId = elementConfig.formId;
          var startDate = elementConfig.startDate || new Date().toISOString().split('T')[0];
          var endDate = elementConfig.endDate;
          var inputSelector = `#selected-slot-${elementId}`;
          var $inputElement = $(inputSelector)
          $(`input${inputSelector}.required`, context).once('remove-required').each(function () {
              $(this).removeAttr('required').removeAttr('aria-required');
              $(`#slots-container-${elementId}`).attr('required', 'required');
          });


          fetchDays(formId, elementId, startDate);
          fetchSlots(formId, elementId, startDate);

          // Function to fetch and display days
          function fetchDays(formId, elementId, date) {
            var daysUrl = `/get-days/${formId}/${elementId}/${date}`;
            var $calendarContainer = $(`#calendar-container-${elementId}`, context);
            var currentDate = new Date(date);
            var currentYear = currentDate.getFullYear();
            var currentMonth = currentDate.getMonth();
            var $slotsContainer = $(`#slots-container-${elementId}`, context);
            $slotsContainer.off('click.WebformBookingDays');

          $.getJSON(daysUrl, function (daysData) {
            var monthSelect = createMonthSelect(startDate,date,endDate);
            $calendarContainer.empty();
            $calendarContainer.append(monthSelect);

            // Generate week days header
            var weekDaysHtml = '<div class="week-days">';
            var weekDays = [Drupal.t('Mon'), Drupal.t('Tue'), Drupal.t('Wed'), Drupal.t('Thu'), Drupal.t('Fri'), Drupal.t('Sat'), Drupal.t('Sun')];
            weekDays.forEach(function (weekDay) {
              weekDaysHtml += `<div class="week-day">${weekDay}</div>`;
            });
            weekDaysHtml += '</div>';
            $calendarContainer.append(weekDaysHtml);

            // Determine the first day of the month
            var firstDay = new Date(currentYear, currentMonth, 1).getDay();
            var emptyDays = (firstDay === 0 ? 6 : firstDay - 1);
            var daysInMonth = new Date(currentYear, currentMonth + 1, 0).getDate();
            var daysHtml = '<div class="calendar-days">';
            for (var i = 0; i < emptyDays; i++) {
              daysHtml += '<div class="calendar-day empty"></div>'; // Empty divs for alignment
            }
            for (var day = 1; day <= daysInMonth; day++) {
              var fullDate = `${currentYear}-${(currentMonth + 1).toString().padStart(2, '0')}-${day.toString().padStart(2, '0')}`;
              var dayClass = 'calendar-day';
              if (daysData.includes(fullDate)) {
                dayClass += ' available';
              }
              daysHtml += `<div class="${dayClass}" data-date="${fullDate}">${day}</div>`;
            }
            daysHtml += '</div>';
            $calendarContainer.append(daysHtml);
            $(`#calendar-container-${elementId} .calendar-day.available`, context).first().addClass('active');

            // Bind event handler to month select
            $(`#month-select-${elementId}`, context).once('WebformBooking').change(function () {
              if ($(this).val()){
                var selectedMonthYear = $(this).val().split('-');
                var year = selectedMonthYear[0];
                var month = selectedMonthYear[1];
                resetSlots(elementId);
                fetchDays(formId, elementId, `${year}-${month}-01`);
              }
            });

            // Bind event handler to available days
            $('.calendar-day.available', context).once('WebformBooking').on('click.WebformBookingDays', function () {
              $(`#calendar-container-${elementId} .calendar-day`).removeClass('active');
              $(this).addClass('active');
              var selectedDate = $(this).data('date');
              resetSlots(elementId);
              fetchSlots(formId, elementId, selectedDate);
            });
            var $availableDays = $(`#calendar-container-${elementId} .calendar-day.available`, context);
            if ($availableDays.length > 0) {
              var firstAvailableDay = $availableDays.first().data('date');
              $availableDays.first().addClass('active'); // Mark it as active
              fetchSlots(formId, elementId, firstAvailableDay); // Fetch slots for this day
            } else {
              // If no available days, clear slots container
              $(`#slots-container-${elementId}`, context).empty();
            }
          });
        }

        function createMonthSelect(startDate, selectedDate, endDate) {
          var currentDate = new Date();
          var start = new Date(startDate);
          var selected = new Date(selectedDate);
          var end = endDate ? new Date(endDate) : new Date(currentDate.getFullYear() + 1, currentDate.getMonth(), currentDate.getDate());

          // If selectedDate is before today, adjust to start from today
          if (selected < currentDate) {
            selected = currentDate;
          }

          // Ensure end date is within a year from the start or selected date, whichever is later
          var oneYearFromStartOrSelected = new Date(Math.max(start, selected));
          oneYearFromStartOrSelected.setFullYear(oneYearFromStartOrSelected.getFullYear() + 1);
          if (end > oneYearFromStartOrSelected) {
            end = oneYearFromStartOrSelected;
          }

          var monthSelect = `<select id="month-select-${elementId}">`;

          // Ensure we don't go before start date or after end date
          for (var year = start.getFullYear(); year <= end.getFullYear(); year++) {
            var firstMonth = year === start.getFullYear() ? start.getMonth() : 0;
            var lastMonth = year === end.getFullYear() ? end.getMonth() : 11;

            for (var month = firstMonth; month <= lastMonth; month++) {
              var optionValue = `${year}-${(month + 1).toString().padStart(2, '0')}`;
              var isSelected = year === selected.getFullYear() && month === selected.getMonth();
              var monthName = new Date(year, month).toLocaleString('default', { month: 'long' });
              monthSelect += `<option value="${optionValue}"${isSelected ? ' selected' : ''}>${monthName} ${year}</option>`;
            }
          }

          monthSelect += '</select>';
          return monthSelect;
        }

        // Function to fetch and display time slots
          function fetchSlots(formId, elementId, date) {
          var slotsUrl = `/get-slots/${formId}/${elementId}/${date}`;
          var $slotsContainer = $(`#slots-container-${elementId}`, context);

          $.getJSON(slotsUrl, function (slotsData) {
            $slotsContainer.empty(); // Clear previous slots
            slotsData.forEach(function (slot) {
              if (slot.time) {
                var slotElement = `<div class="calendar-slot ${slot.status}" data-time="${slot.time.split('-')[0]}">${slot.time}</div>`;
                $slotsContainer.append(slotElement);
              }
            });

            // Bind click events to available slots
            $('.calendar-slot.available', $slotsContainer).on('click', function () {
              resetSlots(elementId);
              $(this).addClass('selected');
              var time = $(this).data('time');
              selectSlot(date, time);
            });
          });
        }

        // Set the value of the hidden field
        function selectSlot(date, time) {
          var dateTime = date + ' ' + time;
          $(`#selected-slot-${elementId}`).val(dateTime);
        }

        function resetSlots(elementId) {
          $(`#selected-slot-${elementId}`).val('');
          $(`#slots-container-${elementId} .calendar-slot`, context).removeClass('selected');
        }

        // Validate the form
        $('form').on('submit', function (e) {
          if ($(`#slots-container-${elementId}`).attr('required') === 'required') {
            var selectedSlot = $(`#slots-container-${elementId} .calendar-slot.selected`);
            if (selectedSlot.length === 0) {
              e.preventDefault();
              alert('Please select a slot.');
              $('html, body').animate({
                scrollTop: $(`#slots-container-${elementId}`).offset().top
              }, 1000);
              $(`#slots-container-${elementId}`).addClass('highlight');
              return false;
            }
          }
        });
      })
    }
    }
  };
})(jQuery, Drupal);

==> webform_booking-1.0.8.tar.gz: webform_booking/js/webform_booking.js <==
(function ($, Drupal) {
  Drupal.behaviors.WebformBooking = {
    attach: function (context, settings) {
      if (settings.webform_booking && settings.webform_booking.elements) {
        Object.keys(settings.webform_booking.elements).forEach(function (key) {
          var elementConfig = settings.webform_booking.elements[key]; // Correctly define elementConfig
          var elementId = elementConfig.elementId;
          var required = elementConfig.required;
          var formId = elementConfig.formId;
          var startDate = elementConfig.startDate || new Date().toISOString().split('T')[0];
          var endDate = elementConfig.endDate;

          fetchDays(formId, elementId, startDate);
          fetchSlots(formId, elementId, startDate);

          // Required slots
          var inputSelector = `#selected-slot-${elementId}`;
          $(`input${inputSelector}.required`, context).once('remove-required').each(function () {
            $(this).removeAttr('required').removeAttr('aria-required');
            $(`#slots-container-${elementId}`).attr('required', 'required');
          });

          var formItem = document.querySelector(`.js-form-item-${elementId}`);
          if (formItem) {
            var observer = new MutationObserver(function (mutations) {
              mutations.forEach(function (mutation) {
                if (mutation.attributeName === 'style') {
                  var displayStyle = formItem.style.display;
                  var slotsContainer = $(`#slots-container-${elementId}`, context);
                  if (displayStyle === 'block' && required) {
                    slotsContainer.attr({ 'required': 'required', 'aria-required': 'true' });
                  } else {
                    slotsContainer.removeAttr('required').removeAttr('aria-required');
                  }
                }
              });
            });
            observer.observe(formItem, { attributes: true, attributeFilter: ['style'] });
          }

          // Function to fetch and display days
          function fetchDays(formId, elementId, date) {
            var daysUrl = `/get-days/${formId}/${elementId}/${date}`;
            var $calendarContainer = $(`#calendar-container-${elementId}`, context);
            var currentDate = new Date(date);
            var currentYear = currentDate.getFullYear();
            var currentMonth = currentDate.getMonth();
            var $slotsContainer = $(`#slots-container-${elementId}`, context);
            $slotsContainer.off('click.WebformBookingDays');

          $.getJSON(daysUrl, function (daysData) {
            var monthSelect = createMonthSelect(startDate,date,endDate);
            $calendarContainer.empty();
            $calendarContainer.append(monthSelect);

            // Generate week days header
            var weekDaysHtml = '<div class="week-days">';
            var weekDays = [Drupal.t('Mon'), Drupal.t('Tue'), Drupal.t('Wed'), Drupal.t('Thu'), Drupal.t('Fri'), Drupal.t('Sat'), Drupal.t('Sun')];
            weekDays.forEach(function (weekDay) {
              weekDaysHtml += `<div class="week-day">${weekDay}</div>`;
            });
            weekDaysHtml += '</div>';
            $calendarContainer.append(weekDaysHtml);

            // Determine the first day of the month
            var firstDay = new Date(currentYear, currentMonth, 1).getDay();
            var emptyDays = (firstDay === 0 ? 6 : firstDay - 1);
            var daysInMonth = new Date(currentYear, currentMonth + 1, 0).getDate();
            var daysHtml = '<div class="calendar-days">';
            for (var i = 0; i < emptyDays; i++) {
              daysHtml += '<div class="calendar-day empty"></div>'; // Empty divs for alignment
            }
            for (var day = 1; day <= daysInMonth; day++) {
              var fullDate = `${currentYear}-${(currentMonth + 1).toString().padStart(2, '0')}-${day.toString().padStart(2, '0')}`;
              var dayClass = 'calendar-day';
              if (daysData.includes(fullDate)) {
                dayClass += ' available';
              }
              daysHtml += `<div class="${dayClass}" data-date="${fullDate}">${day}</div>`;
            }
            daysHtml += '</div>';
            $calendarContainer.append(daysHtml);
            $(`#calendar-container-${elementId} .calendar-day.available`, context).first().addClass('active');

            // Bind event handler to month select
            $(`#month-select-${elementId}`, context).once('WebformBooking').change(function () {
              if ($(this).val()){
                var selectedMonthYear = $(this).val().split('-');
                var year = selectedMonthYear[0];
                var month = selectedMonthYear[1];
                resetSlots(elementId);
                fetchDays(formId, elementId, `${year}-${month}-01`);
              }
            });

            // Bind event handler to available days
            $('.calendar-day.available', context).once('WebformBooking').on('click.WebformBookingDays', function () {
              $(`#calendar-container-${elementId} .calendar-day`).removeClass('active');
              $(this).addClass('active');
              var selectedDate = $(this).data('date');
              resetSlots(elementId);
              fetchSlots(formId, elementId, selectedDate);
            });
            var $availableDays = $(`#calendar-container-${elementId} .calendar-day.available`, context);
            if ($availableDays.length > 0) {
              var firstAvailableDay = $availableDays.first().data('date');
              $availableDays.first().addClass('active'); // Mark it as active
              fetchSlots(formId, elementId, firstAvailableDay); // Fetch slots for this day
            } else {
              // If no available days, clear slots container
              $(`#slots-container-${elementId}`, context).empty();
            }
          });
        }

        function createMonthSelect(startDate, selectedDate, endDate) {
          var currentDate = new Date();
          var start = new Date(startDate);
          var selected = new Date(selectedDate);
          var end = endDate ? new Date(endDate) : new Date(currentDate.getFullYear() + 1, currentDate.getMonth(), currentDate.getDate());

          // If selectedDate is before today, adjust to start from today
          if (selected < currentDate) {
            selected = currentDate;
          }

          // Ensure end date is within a year from the start or selected date, whichever is later
          var oneYearFromStartOrSelected = new Date(Math.max(start, selected));
          oneYearFromStartOrSelected.setFullYear(oneYearFromStartOrSelected.getFullYear() + 1);
          if (end > oneYearFromStartOrSelected) {
            end = oneYearFromStartOrSelected;
          }

          var monthSelect = `<select id="month-select-${elementId}">`;

          // Ensure we don't go before start date or after end date
          for (var year = start.getFullYear(); year <= end.getFullYear(); year++) {
            var firstMonth = year === start.getFullYear() ? start.getMonth() : 0;
            var lastMonth = year === end.getFullYear() ? end.getMonth() : 11;

            for (var month = firstMonth; month <= lastMonth; month++) {
              var optionValue = `${year}-${(month + 1).toString().padStart(2, '0')}`;
              var isSelected = year === selected.getFullYear() && month === selected.getMonth();
              var monthName = new Date(year, month).toLocaleString('default', { month: 'long' });
              monthSelect += `<option value="${optionValue}"${isSelected ? ' selected' : ''}>${monthName} ${year}</option>`;
            }
          }

          monthSelect += '</select>';
          return monthSelect;
        }

        // Function to fetch and display time slots
          function fetchSlots(formId, elementId, date) {
          var slotsUrl = `/get-slots/${formId}/${elementId}/${date}`;
          var $slotsContainer = $(`#slots-container-${elementId}`, context);

          $.getJSON(slotsUrl, function (slotsData) {
            $slotsContainer.empty(); // Clear previous slots
            slotsData.forEach(function (slot) {
              if (slot.time) {
                var slotElement = `<div class="calendar-slot ${slot.status}" data-time="${slot.time.split('-')[0]}">${slot.time}</div>`;
                $slotsContainer.append(slotElement);
              }
            });

            // Bind click events to available slots
            $('.calendar-slot.available', $slotsContainer).on('click', function () {
              resetSlots(elementId);
              $(this).addClass('selected');
              var time = $(this).data('time');
              selectSlot(date, time);
            });
          });
        }

        // Set the value of the hidden field
        function selectSlot(date, time) {
          var dateTime = date + ' ' + time;
          $(`#selected-slot-${elementId}`).val(dateTime);
        }

        function resetSlots(elementId) {
          $(`#selected-slot-${elementId}`).val('');
          $(`#slots-container-${elementId} .calendar-slot`, context).removeClass('selected');
        }

        // Validate the form
        $('form', context).once('webformBookingValidation').on('submit', function (e) {
          $('[id^=slots-container-]', context).removeClass('highlight');
          let isSubmissionValid = true;
          $('[id^=slots-container-]', context).each(function () {
            let elementId = this.id;
            if ($(this).attr('required') === 'required') {
              var selectedSlot = $(`.calendar-slot.selected`, this);
              if (selectedSlot.length === 0) {
                e.preventDefault();
                alert('Please select a slot.');
                $('html, body').animate({
                  scrollTop: $(`#${elementId}`).offset().top
                }, 1000);
                $(`#${elementId}`).addClass('highlight');
                isSubmissionValid = false;
                return false;
              }
            }
          });

          return isSubmissionValid;
        });
      })
    }
    }
  };
})(jQuery, Drupal);
